@@ -1,4 +1,4 @@
-from idegui import IDEWindow
+from idegui.window import IDEWindow
 
 
 def is_delete(word: str):
