@@ -22,7 +22,7 @@ try:
 except (ImportError, ModuleNotFoundError):
     raise SystemExit('must install chardet')
 
-from idegui import ResultBox
+from idegui.popup import ResultBox
 
 if tk.TkVersion < 8.5 or tk.TclVersion < 8.5:
     raise SystemExit('It need tkinter and tcl (version >= 8.5)')
